require 'spec_helper'
require 'collins_client'

describe 'Collins API' do
  it 'gets an asset' do
    api = FactoryGirl.build(:api)
    asset = api.safe_find_exact(:hostname => FactoryDefaults::MOCK_ASSET_HOSTNAME,
                                :details  => true)
    expect(asset).to be_an_instance_of(Enc::CollinsHelper::Node::NodeAsset)
    expect(asset.get_attribute('HOSTNAME')).to eq(FactoryDefaults::MOCK_ASSET_HOSTNAME)
  end

  it 'searches for missing asset' do
    api = FactoryGirl.build(:api)
    expect{api.safe_find_exact(:hostname => 'missing', :details => true)}.
        to raise_exception(Enc::CollinsHelper::Api::NoAssets, 'No assets found')
  end

  it 'searches for too many assets' do
    api = FactoryGirl.build(:api)
    expect{api.safe_find_exact(:hostname => 'toomany', :details => true)}.
        to raise_exception(Enc::CollinsHelper::Api::TooManyAssets, 'Too many assets')
  end

  it 'seaches asset using invalid collins host' do
    api = FactoryGirl.build(:api_timeout)
    expect{api.safe_find(:hostname => FactoryDefaults::MOCK_ASSET_HOSTNAME, :details => true)}.
        to raise_exception(Enc::CollinsHelper::Api::CannotConnect)
  end

  it 'seaches asset using invalid credentials' do
    api = FactoryGirl.build(:api_unauthorized)
    expect{api.safe_find(:hostname => FactoryDefaults::MOCK_ASSET_HOSTNAME, :details => true)}.
        to raise_exception(Collins::AuthenticationError)
  end

  it 'seaches asset using invalid role' do
    api = FactoryGirl.build(:api_forbidden)
    expect{api.safe_find(:hostname => FactoryDefaults::MOCK_ASSET_HOSTNAME, :details => true)}.
        to raise_exception(Collins::RequestError)
  end

  it 'seaches asset and gets an unknown error' do
    api = FactoryGirl.build(:api_error)
    expect{api.safe_find(:hostname => FactoryDefaults::MOCK_ASSET_HOSTNAME, :details => true)}.
        to raise_exception(Collins::RequestError)
  end
end
