require 'spec_helper'
require 'yaml'

describe 'ENC Builder' do
  it 'builds the asset in yaml' do
    node = FactoryGirl.build(:node_asset)
    builder = FactoryGirl.build(:builder)
    expect(builder.to_yaml).to be_an_instance_of(String)
    expect(YAML.load(builder.to_yaml)).to be_an_instance_of(Hash)
    expect(YAML.load(builder.to_yaml)['parameters']['deployment_environment']).to eq(node.get_deployment_environment)
  end

  it 'loads the asset from yaml' do
    node = FactoryGirl.build(:node_asset)
    builder = FactoryGirl.build(:builder)
    expect(YAML.load(builder.to_yaml)).to be_an_instance_of(Hash)
    expect(YAML.load(builder.to_yaml)['parameters']['deployment_environment']).to eq(node.get_deployment_environment)
  end

  it 'builds the required enc output when the enc is enabled' do
    node = FactoryGirl.build(:node_asset)
    builder = FactoryGirl.build(:builder)
    expect(YAML.load(builder.to_yaml)).to be_an_instance_of(Hash)
    expect(YAML.load(builder.to_yaml)['parameters']['deployment_environment']).to eq(node.get_deployment_environment)
    expect(YAML.load(builder.to_yaml)['parameters']['datacenter']).to eq(node.get_datacenter)
    expect(YAML.load(builder.to_yaml)['parameters']['roles'].split(',')).to eq(node.get_roles)
    expect(YAML.load(builder.to_yaml)['parameters']['roles']).to eq(node.get_roles.join(','))
    expect(YAML.load(builder.to_yaml)['parameters']['role1']).to eq(node.get_roles_by_index[0])
    expect(YAML.load(builder.to_yaml)['parameters']['role2']).to eq(node.get_roles_by_index[1])
    expect(YAML.load(builder.to_yaml)['parameters']['role3']).to eq(node.get_roles_by_index[2])
    expect(YAML.load(builder.to_yaml)['parameters']['collins']).to eq({'TAG'    => node.tag,
                                                                       'STATE'  => node.state.name,
                                                                       'STATUS' => node.status}.
                                                                        merge!(node.get_flattened_attributes))
    expect(YAML.load(builder.to_yaml)['parameters']['collins']['HOSTNAME']).to eq(node.get_hostname)
  end

  it 'builds the required enc output when the enc is not enabled' do
    builder = FactoryGirl.build(:builder_enc_disabled)
    expect(builder.to_yaml).to eq("--- ''\n")
  end

  it 'builds the required enc output when the asset does not exist' do
    builder = FactoryGirl.build(:builder_blank_asset)
    expect(builder.to_yaml).to eq("--- ''\n")
  end
end
