require 'spec_helper'

describe 'Collins Node Asset' do
  it 'should have hostname set' do
    node = FactoryGirl.build(:node_asset)
    expect(node.get_hostname).to eq(FactoryDefaults::MOCK_ASSET_HOSTNAME)
  end

  it 'should have a datacenter set' do
    node = FactoryGirl.build(:node_asset)
    expect(node.get_datacenter).to eq('jcadev')
  end

  it 'should have a deployment_environmnet' do
    node = FactoryGirl.build(:node_asset)
    expect(node.get_deployment_environment).to eq('dev')
  end

  it 'should have a default puppet environment' do
    node = FactoryGirl.build(:node_asset, puppet_environment: nil)
    expect(node.get_puppet_environment).to eq('production')
  end

  it 'should have a variable puppet environment' do
    node = FactoryGirl.build(:node_asset, puppet_environment: 'fake_env')
    expect(node.get_puppet_environment).to eq('fake_env')
  end

  it 'is a valid asset' do
    node = FactoryGirl.build(:node_asset)
    expect(node.is_valid?).to eq(true)
  end

  it 'is not a valid asset due to missing datacenter' do
    node = FactoryGirl.build(:node_asset, datacenter: nil)
    expect(node.is_valid?).to eq(false)
    expect{node.get_datacenter}.to raise_exception(Enc::CollinsHelper::Node::NoDatacenter,
                                                   'The node does not have a puppet_datacenter tag set')
  end

  it 'is not a valid asset due to missing deployment environment' do
    node = FactoryGirl.build(:node_asset, environment: nil)
    expect(node.is_valid?).to eq(false)
    expect{node.get_deployment_environment}.to raise_exception(Enc::CollinsHelper::Node::NoDeploymentEnvironment,
                                                               'The node does not have an environment tag set')
  end

  it 'is not a valid asset due to missing hostname' do
    node = FactoryGirl.build(:node_asset, hostname: nil)
    expect(node.is_valid?).to eq(false)
    expect{node.get_hostname}.to raise_exception(Enc::CollinsHelper::Node::NoHostname,
                                                 'The node does not have a hostname tag set')
  end
end
