require 'spec_helper'

describe 'ENC Runner' do
  before :all do
    @config = FactoryGirl.build(:config)
    @cache = FactoryGirl.build(:node_cache)
  end

  it 'gets an instance of the builder' do
    node = FactoryGirl.build(:node_asset)
    runner = FactoryGirl.build(:runner)
    expect(runner.build(node.get_hostname)).to be_an_instance_of(Enc::Builder)
  end

  it 'gets an instance of the builder even if the asset does not have the puppet_enc tag set' do
    runner = FactoryGirl.build(:runner)
    node = FactoryGirl.build(:node_asset, puppet_enc: false)
    expect(runner.build(node.get_hostname)).to be_an_instance_of(Enc::Builder)
  end

  it 'falls back to use cache when collins is unavailable' do
    node = FactoryGirl.build(:node_asset)
    runner = FactoryGirl.build(:runner_fallback)
    @cache.write(node.get_hostname, node)
    expect(@cache.exists?(node.get_hostname)).to eq(true)
    expect(runner.build(node.get_hostname)).to be_an_instance_of(Enc::Builder)
  end

  it 'falls back to use cache when the asset does not exist' do
    runner = FactoryGirl.build(:runner)
    expect(runner.build('missing')).to be_an_instance_of(Enc::Builder)
    expect(@cache.exists?('missing')).to eq(true)
  end

  it 'exits when neither collins nor the local cache is available' do
    node = FactoryGirl.build(:node_asset)
    runner = FactoryGirl.build(:runner_fallback)
    expect{runner.build(node.get_hostname)}.to raise_exception(SystemExit)
    expect(@cache.exists?(node.get_hostname)).to eq(false)
  end
end