require 'webmock/rspec'
require 'enc'
require 'json'
require 'factories'

WebMock.disable_net_connect!(allow_localhost: true)

RSpec.configure do |config|
  good_response = FactoryGirl.build(:collins_response)
  missing_asset_response = FactoryGirl.build(:collins_response, hostname: 'missing')
  good_response_headers = FactoryGirl.build(:collins_response_headers)
  too_many_assets_response = FactoryGirl.build(:collins_response_multiple_assets, hostname: 'toomany')

  config.before(:each) do
    stub_request(:get, "#{FactoryDefaults::MOCK_COLLINS_USERNAME}:#{FactoryDefaults::MOCK_COLLINS_PASSWORD}@
#{FactoryDefaults::MOCK_COLLINS_HOST}
/api/assets?attribute=hostname%3B%5E#{FactoryDefaults::MOCK_ASSET_HOSTNAME}$&details=true").
        to_return(status: 200,
                  body: good_response.to_json,
                  headers: good_response_headers
    )
    stub_request(:get, "#{FactoryDefaults::MOCK_COLLINS_USERNAME}:#{FactoryDefaults::MOCK_COLLINS_PASSWORD}@
#{FactoryDefaults::MOCK_COLLINS_HOST}
/api/assets?attribute=hostname%3B%5Emissing$&details=true").
        to_return(status: 200,
                  body: missing_asset_response.to_json,
                  headers: good_response_headers
    )
    stub_request(:get, "#{FactoryDefaults::MOCK_COLLINS_USERNAME}:#{FactoryDefaults::MOCK_COLLINS_PASSWORD}@
#{FactoryDefaults::MOCK_COLLINS_HOST}
/api/assets?attribute=hostname%3B%5Etoomany$&details=true").
        to_return(status: 200,
                  body: too_many_assets_response.to_json,
                  headers: good_response_headers
    )
    stub_request(:get, FactoryDefaults::MOCK_COLLINS_URL).
        to_return(status: 200,
                  body: 'response body',
                  headers: {}
    )
    stub_request(:any, /shouldneverexist99.jivehostedblah.com/).to_timeout
    stub_request(:get, /willreturn401.jivehostedblah.com/).
        to_return(status: 401)
    stub_request(:get, /willreturn403.jivehostedblah.com/).
        to_return(status: 403)
    stub_request(:get, /willreturn500.jivehostedblah.com/).
        to_return(status: 500)

    FileUtils::mkdir_p(FactoryDefaults::MOCK_ENC_CACHE_DIR)
    FileUtils::mkdir_p(FactoryDefaults::MOCK_ENC_CONF_DIR)
    FileUtils::mkdir_p(FactoryDefaults::MOCK_ENC_LOG_DIR)
  end

  config.after(:each) do
    FileUtils.rm_rf(FactoryDefaults::MOCK_ENC_CACHE_DIR)
    FileUtils.rm_rf(FactoryDefaults::MOCK_ENC_CONF_DIR)
    FileUtils.rm_rf(FactoryDefaults::MOCK_ENC_LOG_DIR)
  end
end

